-- config.lua
local M = {}

-- Display modes
M.modes = {
    float = "float",
    buffer = "buffer",
    hsplit = "hsplit",
    vsplit = "vsplit",
    tab = "tab",
}

local defaults = {
    display = {
        default_mode = M.modes.float,
        picker = true,
        float = {
            maxwidth = 80,
            maxheight = 40,
            border = "rounded",
            title = true,
            style = "minimal",
            auto_focus = true,
            anchor = "bottom_right",
            offset = { row = -2, col = -2 },
        },
        window = {
            width = 0.4,
            height = 0.25,
            position = "bottom|right",
            floating = false,
            border = "none",
        },
    },
    integrations = {
        treesitter = {
            enabled = true,  -- Enable Treesitter integration
            highlight = true, -- Enable syntax highlighting
            langs = {        -- Language mapping for different doc types
                lsp = "markdown",
                help = "vimdoc",
                -- Remove man from default treesitter langs since it's not commonly available
            }
        }
    },
    sources = {
        lsp = { enabled = true },
        vim = { enabled = true },
        man = { enabled = true },
    },
    priority = { "LSP", "Vim", "Man" },
    mappings = {
        close = "<leader>dc",
    },
}

local valid_positions = {
    horizontal = { top = true, bottom = true },
    vertical = { left = true, right = true }
}

function M.setup(opts)
    -- Validate split positions if provided
    if opts and opts.display and opts.display.window and opts.display.window.position then
        local pos = opts.display.window.position
        if pos:find("|") then
            local vsplit, hsplit = pos:match("([^|]+)|([^|]+)")
            if not (valid_positions.vertical[vsplit] and valid_positions.horizontal[hsplit]) and
               not (valid_positions.horizontal[vsplit] and valid_positions.vertical[hsplit]) then
                error("Invalid position combination: " .. pos)
            end
        end
    end

    M.options = vim.tbl_deep_extend("force", defaults, opts or {})
end

M.setup()

return M
