local M = {}

local health = vim.health or require("health")

function M.check()
    health.report_start("odis.nvim")

    -- Check for required dependencies
    if vim.fn.executable("man") == 1 then
        health.report_ok("man command is available")
    else
        health.report_warn("man command not found, man page documentation will be disabled")
    end

    -- Check LSP
    if #vim.lsp.get_active_clients() > 0 then
        health.report_ok("LSP clients are active")
    else
        health.report_info("No active LSP clients found")
    end

    -- Check UI requirements
    local has_notify, _ = pcall(require, "notify")
    if has_notify then
        health.report_ok("nvim-notify is available")
    else
        health.report_info("nvim-notify not found, falling back to vim.notify")
    end
end

return M
