local M = {}
local config = require("odis.config")
local window = require("odis.window")
local sources = require("odis.sources")

function M.setup(opts)
    config.setup(opts)
    if not M._maps_setup then
        vim.keymap.set('n', config.options.mappings.close, window.close_window, { silent = true })
        M._maps_setup = true
    end
    M.options = config.options
end

-- Re-export modes
M.modes = config.modes

function M.show_documentation(display_mode, override_word)
    local word = override_word or vim.fn.expand("<cword>")
    if word == "" then return end

    display_mode = display_mode or config.options.display.default_mode

    sources.get_documentation(word, function(found_sources)
        if #found_sources == 1 or not config.options.display.picker then
            local source = found_sources[1]
            local handlers = {
                LSP = function() sources.display_documentation(source.doc, display_mode, "LSP") end,
                Man = function() sources.display_man_page(word, display_mode) end,
                Vim = function() sources.display_vim_help(word, display_mode) end,
            }
            if handlers[source.name] then handlers[source.name]() end
        else
            vim.ui.select(found_sources, {
                prompt = "Select documentation source:",
                format_item = function(item) return item.name end,
                kind = "documentation_source"
            }, function(choice)
                if not choice then return end
                local handlers = {
                    LSP = function() sources.display_documentation(choice.doc, display_mode, "LSP") end,
                    Man = function() sources.display_man_page(word, display_mode) end,
                    Vim = function() sources.display_vim_help(word, display_mode) end,
                }
                if handlers[choice.name] then handlers[choice.name]() end
            end)
        end
    end)
end

return M
