local M = {}
local config = require("odis.config")

function M.setup_treesitter(buf, source_type)
    if not config.options.integrations.treesitter.enabled then
        return
    end

    -- Skip treesitter for source types that don't need it
    if source_type:lower() == "man" then
        return
    end

    local has_ts, ts = pcall(require, "nvim-treesitter")
    if not has_ts then
        return
    end

    local lang = config.options.integrations.treesitter.langs[source_type:lower()]
    if not lang then
        return
    end

    local ok, parser_ok = pcall(vim.treesitter.language.inspect, lang)
    if ok and parser_ok and config.options.integrations.treesitter.highlight then
        vim.api.nvim_buf_set_option(buf, "syntax", "")  -- Disable regular syntax
        pcall(vim.treesitter.start, buf, lang)  -- Enable treesitter highlighting
    end
end

-- Escape special pattern characters in a string
function M.escape_pattern(text)
    return text:gsub("[%(%)%.%%%+%-%*%?%[%]%^%$]", "%%%1")
end

-- Safe string split with fallback
function M.split(str, sep)
    if str == nil then return {} end
    if sep == nil then sep = "%s" end
    local t = {}
    for s in string.gmatch(str, "([^"..sep.."]+)") do
        table.insert(t, s)
    end
    return t
end

-- Check if a source type needs syntax highlighting
function M.needs_highlighting(source_type)
    return source_type:lower() ~= "man" and 
           config.options.integrations.treesitter.enabled and
           config.options.integrations.treesitter.highlight
end

return M
